@@ -34,6 +34,7 @@ class Control(object):
             compartments=None,
             plots=None,
             workflows=None,
+            args=None,
     ):
         if workflows is None:
             workflows = {}
@@ -52,7 +53,7 @@ class Control(object):
             self.out_dir = out_dir
 
         # arguments
-        self.args = self.add_arguments()
+        self.args = self.parse_args(args)
 
         if self.args.experiment:
             experiment_id = str(self.args.experiment)
@@ -62,7 +63,7 @@ class Control(object):
             workflow_id = str(self.args.workflow)
             self.run_workflow(workflow_id)
 
-    def add_arguments(self):
+    def parse_args(self, args=None):
         parser = argparse.ArgumentParser(
             description='command line control of experiments'
         )
@@ -78,7 +79,7 @@ class Control(object):
             choices=list(self.experiments_library.keys()),
             help='experiment id to run'
         )
-        return parser.parse_args()
+        return parser.parse_args(args)
 
     def run_experiment(self, experiment_id):
         experiment = self.experiments_library[experiment_id]
@@ -157,7 +158,7 @@ def toy_plot(data, config=None, out_dir='out'):
     plot_simulation_output(data, out_dir=out_dir)
 
 
-def toy_control():
+def toy_control(args=None):
     """ a toy example of control
 
     To run:
@@ -195,13 +196,14 @@ def toy_control():
         compartments=compartment_library,
         plots=plot_library,
         workflows=workflow_library,
-        )
+        args=args,
+    )
 
     return control
 
 
 def test_control():
-    control = toy_control()
+    control = toy_control(args=[])
     control.run_workflow('1')
 
 
