@@ -11,7 +11,7 @@ import logging as log
 from vivarium.core.experiment import pp
 from vivarium.core.process import (
     Deriver,
-    Generator,
+    Factory,
 )
 from vivarium.library.units import units
 from vivarium.core.composition import (
@@ -76,7 +76,7 @@ class Engulf(Deriver):
 
 
 # test
-class ToyAgent(Generator):
+class ToyAgent(Factory):
     defaults = {
         'exchange': {'uptake_rate': 0.1},
         'engulf': {
