@@ -5,10 +5,11 @@ Swap Processes Process
 """
 
 import os
+from typing import Any, Dict
 
 from vivarium.core.process import (
     Deriver,
-    Generator,
+    Factory,
 )
 from vivarium.core.composition import (
     simulate_compartment_in_experiment,
@@ -44,7 +45,7 @@ class SwapProcesses(Deriver):
       to upon trigger.
     """
     name = NAME
-    defaults = {
+    defaults: Dict[str, Any] = {
         'removed_processes': [],
         'new_compartment': None,
         'initial_state': {},
@@ -83,7 +84,7 @@ class SwapProcesses(Deriver):
 
 
 # test
-class ToyDeadCompartment(Generator):
+class ToyDeadCompartment(Factory):
     defaults = {
         'secrete': {
             'secrete_rate': 0.1}}
@@ -99,7 +100,7 @@ class ToyDeadCompartment(Generator):
                 'external': ('external',)}}
 
 
-class ToyLivingCompartment(Generator):
+class ToyLivingCompartment(Factory):
     defaults = {
         'exchange': {'uptake_rate': 0.1},
         'death': {
