@@ -1,4 +1,8 @@
-from __future__ import absolute_import, division, print_function
+'''
+Execute by running: ``python vivarium/process/template_process.py``
+
+TODO: Replace the template code to implement your own process.
+'''
 
 import os
 
@@ -9,6 +13,7 @@ from vivarium.core.composition import (
 )
 from vivarium.plots.simulation_output import plot_simulation_output
 
+
 # a global NAME is used for the output directory and for the process name
 NAME = 'template'
 
@@ -23,18 +28,12 @@ class Template(Process):
 
     # declare default parameters as class variables
     defaults = {
-        'parameter_1': {}
+        'uptake_rate': 0.1,
     }
 
-    def __init__(self, initial_parameters=None):
-        if initial_parameters is None:
-            initial_parameters = {}
-
-        # get the parameters out of initial_parameters if available, or use defaults
-        parameter_1 = self.or_default(
-            initial_parameters, 'parameter_1')
-
-        parameters = {'parameter_1': parameter_1}
+    def __init__(self, parameters=None):
+        # parameters passed into the constructor merge with the defaults
+        # and can be access through the self.parameters class variable
         super(Template, self).__init__(parameters)
 
     def ports_schema(self):
@@ -60,7 +59,7 @@ class Template(Process):
                 }
             },
             'external': {
-                'B': {
+                'A': {
                     '_default': 1.0,
                     '_updater': 'accumulate',
                     '_emit': True,
@@ -75,40 +74,78 @@ class Template(Process):
         return {}
 
     def next_update(self, timestep, states):
+
         # get the states
-        A_state = states['internal']['A']
-        B_state = states['external']['B']
+        internal_A = states['internal']['A']
+        external_A = states['external']['A']
 
-        # calculate output for the states
-        A_update = 0.5 * B_state
-        B_update = -0.5 * B_state
+        # calculate timestep-dependent updates
+        internal_update = self.parameters['uptake_rate'] * external_A * timestep
+        external_update = -1 * internal_update
 
-        # return an update to the states
+        # return an update that mirrors the ports structure
         return {
-            'internal': {'A': A_update},
-            'external': {'B': B_update}}
+            'internal': {
+                'A': internal_update},
+            'external': {
+                'A': external_update}
+        }
 
 
 # functions to configure and run the process
-def run_template_process(out_dir='out'):
-    # initialize the process by passing initial_parameters
-    initial_parameters = {}
-    template_process = Template(initial_parameters)
+def run_template_process():
+    '''Run a simulation of the process.
+
+    Returns:
+        The simulation output.
+    '''
+
+    # initialize the process by passing in parameters
+    parameters = {}
+    template_process = Template(parameters)
+
+    # declare the initial state, mirroring the ports structure
+    initial_state = {
+        'internal': {
+            'A': 0.0
+        },
+        'external': {
+            'A': 1.0
+        },
+    }
 
     # run the simulation
-    sim_settings = {'total_time': 10}
+    sim_settings = {
+        'total_time': 10,
+        'initial_state': initial_state}
     output = simulate_process_in_experiment(template_process, sim_settings)
 
+    return output
+
+
+def test_template_process():
+    '''Test that the process runs correctly.
+
+    This will be executed by pytest.
+    '''
+    output = run_template_process()
+    # TODO: Add assert statements to ensure correct performance.
+
+
+def main():
+    '''Simulate the process and plot results.'''
+    # make an output directory to save plots
+    out_dir = os.path.join(PROCESS_OUT_DIR, NAME)
+    if not os.path.exists(out_dir):
+        os.makedirs(out_dir)
+
+    output = run_template_process()
+
     # plot the simulation output
     plot_settings = {}
     plot_simulation_output(output, plot_settings, out_dir)
 
 
-# run module is run as the main program with python vivarium/process/template_process.py
+# run module with python vivarium/process/template_process.py
 if __name__ == '__main__':
-    # make an output directory to save plots
-    out_dir = os.path.join(PROCESS_OUT_DIR, NAME)
-    if not os.path.exists(out_dir):
-        os.makedirs(out_dir)
-
-    run_template_process(out_dir)
+    main()
